@@ -4,7 +4,7 @@ use warnings;
 #ABSTRACT: NaCl compatible modern, easy-to-use library for  encryption, decryption, signatures, password hashing and more
 package Crypt::NaCl::Sodium;
 our $AUTHORITY = 'cpan:AJGB';
-$Crypt::NaCl::Sodium::VERSION = '1.0.6.1';
+$Crypt::NaCl::Sodium::VERSION = '1.0.7.0';
 use Carp qw( croak );
 use Sub::Exporter;
 
@@ -174,7 +174,7 @@ Crypt::NaCl::Sodium - NaCl compatible modern, easy-to-use library for  encryptio
 
 =head1 VERSION
 
-version 1.0.6.1
+version 1.0.7.0
 
 =head1 SYNOPSIS
 
@@ -247,9 +247,6 @@ version 1.0.6.1
     # constant time comparision of large numbers
     compare($x, $y, $length ) == -1 and print '$x < $y';
 
-    # increment nonce
-    increment($nonce);
-
     # overwrite with null bytes
     memzero($a, $b, ...);
 
@@ -426,16 +423,19 @@ found or when C<max_len> bytes have been written.
 
 =head2 memcmp
 
-    memcmp($a, $b, $length ) or die '$a ne $b';
+    memcmp($a, $b, $length ) or die "\$a ne \$b for length: $length";
 
 Compares strings in constant-time. Returns true if they match, false otherwise.
 
 The argument C<$length> is optional if variables are of the same length. Otherwise it is
 required and cannot be greater then the length of the shorter of compared variables.
 
+B<NOTE:> L<Data::BytesLocker/"memcmp"> provides the same functionality.
+
+    $locker->memcmp($b, $length) or die "\$locker ne \$b for length: $length";
+
 =head2 compare
 
-    # constant time comparision of large numbers
     compare($x, $y, $length ) == -1 and print '$x < $y';
 
 A constant-time version of L</memcmp>, useful to compare nonces and counters
@@ -448,6 +448,10 @@ assumed to be numbers encoded in little-endian format.
 The argument C<$length> is optional if variables are of the same length. Otherwise it is
 required and cannot be greater then the length of the shorter of compared variables.
 
+B<NOTE:> L<Data::BytesLocker/"compare"> provides the same functionality.
+
+    $locker->compare($y, $length) == -1 and print "\$locker < \$y for length: $length";
+
 =head2 memzero
 
     memzero($a, $b, ...);
@@ -466,14 +470,15 @@ If C<$upper_bound> is not specified the maximum value is C<0xffffffff>
 
 =head2 increment
 
-    increment($nonce);
+    increment($nonce, ...);
 
-Increments an arbitrary long unsigned number (in place). Function runs in constant-time
-for a given length of number and considers the number to be encoded in
+B<NOTE:> This function is deprecated and will be removed in next version. Please
+use L<Data::BytesLocker/"increment">.
+
+Increments an arbitrary long unsigned number(s) (in place). Function runs in constant-time
+for a given length of arguments and considers them to be encoded in
 little-endian format.
 
-This function can be used to increment nonces.
-
 =head2 random_bytes
 
     my $bytes = random_bytes($num_of_bytes);
